@@ -352,6 +352,7 @@ class WebSocket(object):
         # These buffer over the build-up of a single frame.
         self._frame_buffer = _FrameBuffer()
         self._cont_data = None
+        self._recving_frames = None
         if enable_multithread:
             self.lock = threading.Lock()
         else:
@@ -432,7 +433,7 @@ class WebSocket(object):
                 self.sock.setsockopt(*opts)
             for opts in self.sockopt:
                 self.sock.setsockopt(*opts)
-            # TODO: we need to support proxy
+            
             address = addrinfo[4]
             try:
                 self.sock.connect(address)
@@ -663,7 +664,10 @@ class WebSocket(object):
         opcode, data = self.recv_data()
         if six.PY3 and opcode == ABNF.OPCODE_TEXT:
             return data.decode("utf-8")
-        return data
+        elif opcode == ABNF.OPCODE_TEXT or opcode == ABNF.OPCODE_BINARY:
+            return data
+        else:
+            return ''
 
     def recv_data(self, control_frame=False):
         """
@@ -681,17 +685,24 @@ class WebSocket(object):
                 # 'NoneType' object has no attribute 'opcode'
                 raise WebSocketException("Not a valid frame %s" % frame)
             elif frame.opcode in (ABNF.OPCODE_TEXT, ABNF.OPCODE_BINARY, ABNF.OPCODE_CONT):
-                if frame.opcode == ABNF.OPCODE_CONT and not self._cont_data:
+                if frame.opcode == ABNF.OPCODE_CONT and not self._recving_frames:
                     raise WebSocketException("Illegal frame")
+
                 if self._cont_data:
                     self._cont_data[1] += frame.data
                 else:
+                    if frame.opcode in (ABNF.OPCODE_TEXT, ABNF.OPCODE_BINARY):
+                        self._recving_frames = frame.opcode
                     self._cont_data = [frame.opcode, frame.data]
 
+                if frame.fin:
+                    self._recving_frames = None
+                
                 if frame.fin or self.fire_cont_frame:
                     data = self._cont_data
                     self._cont_data = None
                     return data
+
             elif frame.opcode == ABNF.OPCODE_CLOSE:
                 self.send_close()
                 return (frame.opcode, frame.data)
@@ -784,6 +795,7 @@ class WebSocket(object):
         """
         if status < 0 or status >= ABNF.LENGTH_16:
             raise ValueError("code is invalid range")
+        self.connected = False
         self.send(struct.pack('!H', status) + reason, ABNF.OPCODE_CLOSE)
 
     def close(self, status=STATUS_NORMAL, reason=six.b("")):
