@@ -28,7 +28,7 @@ from websocket._core import _parse_url, _create_sec_websocket_key
 
 
 # Skip test to access the internet.
-TEST_WITH_INTERNET = False
+TEST_WITH_INTERNET = True
 
 # Skip Secure WebSocket test.
 TEST_SECURE_WS = False
